# Installation

Preferred way to install is as usual (for testing or in isolation):

```bash
$ pipx install spdx-lint
```

For production use or within a virtual python env:

```bash
$ pip install spdx-lint
```

